==> OpenWhisk-1.0.0-sources.tar.gz: OpenWhisk-1.0.0/tests/src/test/scala/org/apache/openwhisk/core/database/azblob/AzureBlobAttachmentStoreCDNTests.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.openwhisk.core.database.azblob

import org.apache.openwhisk.core.entity.WhiskEntity
import org.junit.runner.RunWith
import org.scalatest.junit.JUnitRunner

@RunWith(classOf[JUnitRunner])
class AzureBlobAttachmentStoreCDNTests extends AzureBlobAttachmentStoreBehaviorBase with AzureBlob {
  override lazy val store = makeAzureStore[WhiskEntity]

  override def storeType: String = "AzureBlob_AzureCDN"
  override def azureCdnConfig: String =
    """
      |azure-cdn-config {
      |  domain-name = ${AZ_CDN_DOMAIN}
      |}
    """.stripMargin

  override protected def withFixture(test: NoArgTest) = {
    assume(
      System.getenv("AZ_CDN_DOMAIN") != null,
      "Configure following env variables for test " +
        "to run 'AZ_CDN_DOMAIN' ")
    super.withFixture(test)
  }

  //With AzureCDN deletes are not immediate and instead the objects may live in CDN cache untill TTL
  override protected val lazyDeletes = true

}

==> OpenWhisk-2.0.0-sources.tar.gz: OpenWhisk-2.0.0/tests/src/test/scala/org/apache/openwhisk/core/database/azblob/AzureBlobAttachmentStoreCDNTests.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.openwhisk.core.database.azblob

import org.apache.openwhisk.core.entity.WhiskEntity
import org.junit.runner.RunWith
import org.scalatest.junit.JUnitRunner

@RunWith(classOf[JUnitRunner])
class AzureBlobAttachmentStoreCDNTests extends AzureBlobAttachmentStoreBehaviorBase with AzureBlob {
  override lazy val store = makeAzureStore[WhiskEntity]

  override def storeType: String = "AzureBlob_AzureCDN"
  override def azureCdnConfig: String =
    """
      |azure-cdn-config {
      |  domain-name = ${AZ_CDN_DOMAIN}
      |}
    """.stripMargin

  override protected def withFixture(test: NoArgTest) = {
    assume(
      System.getenv("AZ_CDN_DOMAIN") != null,
      "Configure following env variables for test " +
        "to run 'AZ_CDN_DOMAIN' ")
    super.withFixture(test)
  }

  //With AzureCDN deletes are not immediate and instead the objects may live in CDN cache until TTL
  override protected val lazyDeletes = true

}
